;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "selected-window-accent-mode" "20251205.1215"
  "Accent Selected Window."
  '((emacs "28.1"))
  :url "https://github.com/captainflasmr/selected-window-accent-mode"
  :commit "cfdcf242e2967c131ac01da6565d70a367e10320"
  :revdesc "cfdcf242e296"
  :keywords '("convenience")
  :authors '(("James Dyer" . "captainflasmr@gmail.com"))
  :maintainers '(("James Dyer" . "captainflasmr@gmail.com")))
